From 2987bfa203a8467a697efffa211b90b12858b40b Mon Sep 17 00:00:00 2001
From: hasufell <hasufell@gentoo.org>
Date: Sun, 6 Oct 2013 20:37:28 +0200
Subject: [PATCH] respect flags, add WITH_PGF option, fix echo

---
 util/Makefile | 56 +++++++++++++++++++++++++++++++++++---------------------
 1 file changed, 35 insertions(+), 21 deletions(-)

diff --git a/util/Makefile b/util/Makefile
index e6af415..21a0d17 100644
--- a/util/Makefile
+++ b/util/Makefile
@@ -1,39 +1,53 @@
-GCC = gcc
-CPP = g++ -fpermissive
+# set to anything but "no" to enable
+WITH_PGF=no
 
+ifneq ($(WITH_PGF),no)
 all: pdfconcat ppmtops pgf2pnm
+else
+all: pdfconcat ppmtops
+endif
 
 pdfconcat:
-	$(GCC) -O3 -s -DNDEBUG=1 -DNO_CONFIG=1 -ansi -pedantic -Wunused -Wall -W -Wstrict-prototypes -Wtraditional -Wnested-externs -Winline -Wpointer-arith -Wbad-function-cast -Wcast-qual -Wmissing-prototypes -Wmissing-declarations pdfconcat.c -o pdfconcat
+	$(CC) $(CFLAGS) -DNDEBUG=1 -DNO_CONFIG=1 -ansi -pedantic -Wunused -Wall -W -Wstrict-prototypes -Wtraditional -Wnested-externs -Winline -Wpointer-arith -Wbad-function-cast -Wcast-qual -Wmissing-prototypes -Wmissing-declarations pdfconcat.c -o pdfconcat $(LDFLAGS)
 
 ppmtops:
-	$(GCC) ppmtops.c -o ppmtops
+	$(CC) $(CFLAGS) ppmtops.c -o ppmtops $(LDFLAGS)
 
+ifneq ($(WITH_PGF),no)
 pgf2pnm: main.cpp pnm.cpp
 	@if [ -x /usr/include/libpgf ] ; then \
-	$(CPP) -c main.cpp -o main.o -I/usr/include/libpgf ; \
-	$(CPP) -c pnm.cpp -o pnm.o -I/usr/include/libpgf ; \
-	$(CPP) -o pgf2pnm main.o pnm.o -lpgf ; \
+	$(CXX) $(CXXFLAGS) -fpermissive -c main.cpp -o main.o -I/usr/include/libpgf ; \
+	$(CXX) $(CXXFLAGS) -fpermissive -c pnm.cpp -o pnm.o -I/usr/include/libpgf ; \
+	$(CXX) $(CXXFLAGS) -fpermissive -o pgf2pnm main.o pnm.o $(LDFLAGS) -lpgf ; \
 	else \
-	@echo "libpgf not installed !!" ; \
+	echo "libpgf not installed !!" ; \
 	fi
+endif
 
-install:
+install-common:
 	@if [ -x pdfconcat ] ; then \
-	mkdir -p $(DESTDIR)/usr/bin ; \
-	install -c pdfconcat $(DESTDIR)/usr/bin ; \
-	echo "install -c pdfconcat $(DESTDIR)/usr/bin" ; \
-	mkdir -p $(DESTDIR)/usr/share/man/man1 ; \
-	install -c -m 644 pdfconcat.1 $(DESTDIR)/usr/share/man/man1 ; \
-	echo "install -c pdfconcat.1 $(DESTDIR)/usr/share/man/man1" ; fi
+	mkdir -p "$(DESTDIR)"/usr/bin ; \
+	install -c pdfconcat "$(DESTDIR)"/usr/bin ; \
+	echo "install -c pdfconcat "$(DESTDIR)"/usr/bin" ; \
+	mkdir -p "$(DESTDIR)"/usr/share/man/man1 ; \
+	install -c -m 644 pdfconcat.1 "$(DESTDIR)"/usr/share/man/man1 ; \
+	echo "install -c pdfconcat.1 "$(DESTDIR)"/usr/share/man/man1" ; fi
 	@if [ -x ppmtops ] ; then \
-	mkdir -p $(DESTDIR)/usr/bin ; \
-	install -c ppmtops $(DESTDIR)/usr/bin ; \
-	echo "install -c ppmtops $(DESTDIR)/usr/bin" ; fi
+	mkdir -p "$(DESTDIR)"/usr/bin ; \
+	install -c ppmtops "$(DESTDIR)"/usr/bin ; \
+	echo "install -c ppmtops "$(DESTDIR)"/usr/bin" ; fi
+
+install-pgf:
 	@if [ -x pgf2pnm ] ; then \
-	mkdir -p $(DESTDIR)/usr/bin ; \
-	install -c pgf2pnm $(DESTDIR)/usr/bin ; \
-	echo "install -c pgf2pnm $(DESTDIR)/usr/bin" ; fi
+	mkdir -p "$(DESTDIR)"/usr/bin ; \
+	install -c pgf2pnm "$(DESTDIR)"/usr/bin ; \
+	echo "install -c pgf2pnm "$(DESTDIR)"/usr/bin" ; fi
+
+ifneq ($(WITH_PGF),no)
+install: install-common install-pgf
+else
+install: install-common
+endif
 
 clean:
 	rm -f core *~ *.o pdfconcat ppmtops pgf2pnm
-- 
1.8.3.2

